# tko - Test Engine for Judge Operations

## Install using pip from git

```bash
pipx install git+https://github.com/senapk/tko.git 
```

## Install using pip

```bash
sudo pip install tko
```

## Requirements

Python 3.8 or later with all [requirements.txt](requirements.txt)
dependencies installed, including `build` and `twine`. To install run:

```bash
python -m pip install -U pip
pip install -r requirements.txt
```
